// HTMLParser Library v1.1 - A java-based parser for HTML
// Copyright (C) Dec 31, 2000 Somik Raha
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// For any questions or suggestions, you can write to me at :
// Email :somik@kizna.com
// 
// Postal Address : 
// Somik Raha
// R&D Team
// Kizna Corporation
// Hiroo ON Bldg. 2F, 5-19-9 Hiroo,
// Shibuya-ku, Tokyo, 
// 150-0012, 
// JAPAN
// Tel  :  +81-3-54752646
// Fax : +81-3-5449-4870
// Website : www.kizna.com
//
// Improvements contributed by Nash Tsai (nash_c@users.sourceforge.net)
// Bug fixes contributed by Kaarle Kaila (kaila@users.sourceforge.net)
//

package com.kizna.html;
//////////////////
// Java Imports //
//////////////////
import java.io.*;
import java.util.*;

/////////////////////////
// HTML Parser Imports //
/////////////////////////
import com.kizna.html.tags.HTMLTag;
import com.kizna.html.tags.HTMLEndTag;
import com.kizna.html.scanners.*;

/**
 * HTMLReader builds on the BufferedReader, providing methods to read one element
 * at a time
 */
public class HTMLReader extends BufferedReader
{
	protected int posInLine=-1;
	protected String line;
	protected HTMLNode node = null;
	protected HTMLTagScanner previousOpenScanner = null;
	protected String url;
	private java.io.BufferedReader in;
	private HTMLParser parser;


    protected boolean doSpecialCharExpansion = false;
    void setSpecialCharExpansion(boolean val) {
	doSpecialCharExpansion = val;
    }


	/**
	 * This constructor basically overrides the existing constructor in the
	 * BufferedReader class.
	 */

	public HTMLReader(BufferedReader in, int len)
	{
		super(in,len);
		this.in = in;
		this.parser = null;
	}
	/**
	 * The constructor takes in a reader object, and the url to be read.
	 */
	public HTMLReader(BufferedReader in,String url)
	{
		super(in);
		this.in = in;
		this.url = url;
		this.parser = null;		
	}
/**
 * This method is useful when designing your own scanners. You might need to find out what is the location where the
 * reader has stopped last.
 * @return int Last position read by the reader
 */
public int getLastReadPosition() {
	if (node!=null) return node.elementEnd(); else
	return 0;
}
	/*
	 * Read the next line
	 * @return String containing the line
	 */
	public String getNextLine()
	{
		try
		{
			line = readLine();
			posInLine = 0;
			return line;
		}
		catch (IOException e)
		{
			System.err.println("I/O Exception occurred while reading!");
		}
		return null;
	}
/**
 * Insert the method's description here.
 * Creation date: (12/24/2001 5:27:37 PM)
 * @return com.kizna.html.HTMLParser
 */
public HTMLParser getParser() {
	return parser;
}
	/**
	 * Read the next element
	 * @return HTMLNode - The next node
 	 */
	public HTMLNode readElement() throws IOException
	{
		if (readNextLine())
		{
			do
			{
				line = getNextLine();
			}
			while (line!=null && line.length()==0);

		} else
		posInLine=node.elementEnd()+1;
		if (line==null) return null;
		node = HTMLRemarkNode.find(this,line,posInLine);
		if (node!=null) return node;
		if (line==null) return null;

		node = HTMLStringNode.find(this,line,posInLine);
		if (node!=null) return node;
		if (line==null) return null;
		
		node = HTMLTag.find(this,line,posInLine);
		if (node!=null)
		{
			HTMLTag tag = (HTMLTag)node;
			try
			{
				node = tag.scan(parser.getScanners(),url,this);
				return node;
			}
			catch (IOException e)
			{
				System.err.println("Error! I/O Exception occurred while reading "+url);
			}
		}

		// If we couldnt get a string, then it is probably an end tag
		
		if (line==null) return null;
		node = HTMLEndTag.find(line,posInLine);
		if (node!=null) return node;

	
		return null;
	}
/**
 * Delegates to the BufferedReader's readLine method
 * @return String line read by the reader
 */
public String readLine() throws IOException{

    /* This used to be just:
     *     return in.readLine();
     * But LKM changed it to catch & HTML references and handle them
     * so that our XML parser will be happy 
     */
    String str = in.readLine();
    
    if (str == null)
    	return str;
    else
	return cleanLine(str);
}

    public boolean lookingAtValidChar(int ch, boolean skipPastChar) {
	//        int ch = fMostRecentChar;
        if (ch < 0xD800) {
            if (ch < 0x20 && ch != 0x09 && ch != 0x0A && ch != 0x0D) {
                if (ch == -1)
		    //          return changeReaders().lookingAtValidChar(skipPastChar);
		    return false;
                return false;
            }
            if (skipPastChar) {
		// LKM
		return false;
            }
            return true;
        }
    throw new java.lang.RuntimeException();
    
    
    //        return true;
    }




    public String cleanChars(String str) {
	int i=0;
	String foo="";

	System.out.println("start");
	for (i=0;i<str.length();i++) {
	    int c = str.charAt(i);
	    char ch = str.charAt(i);
	    System.out.println("int: "+c+" ch: '"+ch+"' "+lookingAtValidChar(c, false)+" "+Character.getType(ch));
	    foo += ch;
	}
	System.out.println("end");
	return foo;
    }

public String cleanLine(String str) {

    //    str = cleanChars(str);

    int start   = 0;
    int index  = str.indexOf('&');
    if ( (index == -1) || (!doSpecialCharExpansion) ) {
	/* common case -- no ampersand, just return raw string */
	return str;
    }
    else {
	/* Otherwise, we have to deal with some ampersand */
	//	char array[] = str.toCharArray();
	int inputLen = str.length();
	StringBuffer buf = new StringBuffer(inputLen);

	while(index != -1) {
	    /* copy over what we have so far */
	    /* we copy everything from [start,index) */
	    /* so incrementering start below makes up skip input */
	    /* incrementing index just moves us forward */

	    int len = index-start;
	    if (len > 0)
		buf.append(str.substring(start, index));
	    start = index;

	    /* we have copied everything up to the ampersand.
	       now decide what to do */

	    /* Look at what follows to decide what to do next */
	    
	    if ( ((index + 1) < inputLen) &&
		 Character.isWhitespace(str.charAt(index+1)) ) {
		/* this was just a normal ampersand, 
		   followed by space. convert it to "&amp;" */
		buf.append("&amp;");
		
		/* skip over original amperand, but not the space 
		   following it */
		index++;
		start++;
	    }
	    else {
		int temp1, temp2;

		if (str.startsWith("&nbsp;", index) ||
		    str.startsWith("&emsp;", index) ||
		    str.startsWith("&ensp;", index) ) {
		    /* XML parser doesn't recognize these */

		    /* convert into a normal space */
		    buf.append(' ');
		    
		    /* advance the ampersand *and* the
		       start point to skip the text */
		    len = str.indexOf(';', index) - index + 1;
		    index += len;
		    start += len;
		}
		else if ( str.startsWith("&#",index) &&  
			 ((temp1 = str.indexOf(';', index)) != -1) &&
			 (temp1 < (index+8) ) &&
			 ( ((temp2 = str.indexOf('&',index+1)) == -1) ||
			   (temp1 < temp2) ) ) {
		    /* Above logic checks for string like &#39;
		       We accept anything that starts with & and is then
		       followed by a ';' within 8 chars
		       BEFORE we see another '&' */

		    /* Had problem in this code with "&rsquo;", which the XML
		       parser doesn't handle.  So I added the condition back
		       in that must start with "&#".
		       This will change the behavior of things like "&quot:" -- now the 
		       XML parser should just send them through.  May want a later
		       pass (or here) to process things that we know */

		    /* Our XML parser should be able to handle this --
		     skip over up to the ; */
		    index += temp1 - index + 1;
		}
		else {
		    /* We found some sequence we don't recognize.
		       Convert it to &amp; so the XML parser won't complain */
		    /* The XML parser will convert this to just & */
		    buf.append("&amp;");
		    //buf.append('&');

		    /* skip over original ampersand, but not the space 
		       following it */
		    index++;
		    start++;
		}
	    }

	    /* check for the next ampersand */
	    if (index < inputLen)
		index  = str.indexOf('&', index);
	    else {
		/* break out of loop */
		index = -1;
	    }
	}

	/* do a final copy */
	int len = inputLen-start;
	if (len > 0)
	    buf.append(str.substring(start, inputLen));		

	
	return buf.toString();
    }
}


	/**
	 * Do we need to read the next line ?
	 * @return true - yes/ false - no
	 */
	protected boolean readNextLine()
	{
		if (posInLine==-1 || (line!=null && node.elementEnd()+1>=line.length()))
				return true;
		else return false;
	}
/**
 * The setParser method is used by the parser to put its own object into the reader. This happens internally,
 * so this method is not generally for use by the developer or the user.
 */
public void setParser(HTMLParser newParser) {
	parser = newParser;
}

	/**
	 * Gets the previousOpenScanner.
	 * @return Returns a HTMLTagScanner
	 */
	public HTMLTagScanner getPreviousOpenScanner() {
		return previousOpenScanner;
	}

	/**
	 * Sets the previousOpenScanner.
	 * @param previousOpenScanner The previousOpenScanner to set
	 */
	public void setPreviousOpenScanner(HTMLTagScanner previousOpenScanner) {
		this.previousOpenScanner = previousOpenScanner;
	}


    public static void main(String argv[]) {
	
	String str = argv[0];
	
	System.out.println("Input:\n'"+str+"'");
	
	//	str = cleanLine(str);
	
	System.out.println("Output:\n'"+str+"'");
	
    }


}

